<?php

namespace B2buy\Service\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use B2buy\Service\Http\Requests\BookingRequest;
use B2buy\Service\Interfaces\BookingRepositoryInterface;
use B2buy\Service\Models\Booking;
use B2buy\Service\Forms\Booking as Form;

/**
 * APIController  class for booking.
 */
class BookingAPIController extends BaseController
{

    /**
     * Initialize booking resource controller.
     *
     * @param type BookingRepositoryInterface $booking
     *
     * @return null
     */
    public function __construct(BookingRepositoryInterface $booking)
    {
        parent::__construct();
        $this->repository = $booking;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Service\Repositories\Criteria\BookingResourceCriteria::class);
    }

    /**
     * Display a list of booking.
     *
     * @return Response
     */
    public function index(BookingRequest $request)
    {
        return $this->repository
            ->setPresenter(\B2buy\Service\Repositories\Presenter\BookingPresenter::class)
            ->paginate();
    }

    /**
     * Display booking.
     *
     * @param Request $request
     * @param Model   $booking
     *
     * @return Response
     */
    public function show(BookingRequest $request, Booking $booking)
    {
        return $booking->setPresenter(\B2buy\Service\Repositories\Presenter\BookingListPresenter::class);
        ;
    }

    /**
     * Create new booking.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BookingRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('service::booking.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('service/booking/' . $booking->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('service/booking');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the booking.
     *
     * @param Request $request
     * @param Model   $booking
     *
     * @return Response
     */
    public function update(BookingRequest $request, Booking $booking)
    {
        try {
            $data = $request->all();

            $booking->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('service::booking.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('service/booking/' . $booking->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('service/booking/' . $booking->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the booking.
     *
     * @param Model   $booking
     *
     * @return Response
     */
    public function destroy(BookingRequest $request, Booking $booking)
    {
        try {
            $booking->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('service::booking.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('service/booking/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('service/booking/' . $booking->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
