<?php

namespace B2buy\Service\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use B2buy\Service\Http\Requests\ProviderRequest;
use B2buy\Service\Interfaces\ProviderRepositoryInterface;
use B2buy\Service\Models\Provider;
use B2buy\Service\Forms\Provider as Form;

/**
 * APIController  class for provider.
 */
class ProviderAPIController extends BaseController
{

    /**
     * Initialize provider resource controller.
     *
     * @param type ProviderRepositoryInterface $provider
     *
     * @return null
     */
    public function __construct(ProviderRepositoryInterface $provider)
    {
        parent::__construct();
        $this->repository = $provider;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Service\Repositories\Criteria\ProviderResourceCriteria::class);
    }

    /**
     * Display a list of provider.
     *
     * @return Response
     */
    public function index(ProviderRequest $request)
    {
        return $this->repository
            ->setPresenter(\B2buy\Service\Repositories\Presenter\ProviderPresenter::class)
            ->paginate();
    }

    /**
     * Display provider.
     *
     * @param Request $request
     * @param Model   $provider
     *
     * @return Response
     */
    public function show(ProviderRequest $request, Provider $provider)
    {
        return $provider->setPresenter(\B2buy\Service\Repositories\Presenter\ProviderListPresenter::class);
        ;
    }

    /**
     * Create new provider.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ProviderRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('service::provider.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('service/provider/' . $provider->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('service/provider');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the provider.
     *
     * @param Request $request
     * @param Model   $provider
     *
     * @return Response
     */
    public function update(ProviderRequest $request, Provider $provider)
    {
        try {
            $data = $request->all();

            $provider->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('service::provider.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('service/provider/' . $provider->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('service/provider/' . $provider->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the provider.
     *
     * @param Model   $provider
     *
     * @return Response
     */
    public function destroy(ProviderRequest $request, Provider $provider)
    {
        try {
            $provider->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('service::provider.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('service/provider/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('service/provider/' . $provider->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
