<?php

namespace B2buy\Service\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use B2buy\Service\Interfaces\ProviderRepositoryInterface;

class ProviderPublicController extends BaseController
{
    // use ProviderWorkflow;

    /**
     * Constructor.
     *
     * @param type \B2buy\Provider\Interfaces\ProviderRepositoryInterface $provider
     *
     * @return type
     */
    public function __construct(ProviderRepositoryInterface $provider)
    {
        $this->repository = $provider;
        parent::__construct();
    }

    /**
     * Show provider's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $providers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('service::provider.names'))
            ->view('service::public.provider.index')
            ->data(compact('providers'))
            ->output();
    }


    /**
     * Show provider.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $provider = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($provider->name . trans('service::provider.name'))
            ->view('service::public.provider.show')
            ->data(compact('provider'))
            ->output();
    }

}
