<?php

namespace B2buy\Service\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Service\Models\ProviderAvailability;

class ProviderAvailabilityPolicy
{

    /**
     * Determine if the given user can view the provider_availability.
     *
     * @param UserPolicy $user
     * @param ProviderAvailability $provider_availability
     *
     * @return bool
     */
    public function view(UserPolicy $user, ProviderAvailability $provider_availability)
    {
        if ($user->canDo('service.provider_availability.view') && $user->isAdmin()) {
            return true;
        }

        return $provider_availability->user_id == user_id() && $provider_availability->user_type == user_type();
    }

    /**
     * Determine if the given user can create a provider_availability.
     *
     * @param UserPolicy $user
     * @param ProviderAvailability $provider_availability
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('service.provider_availability.create');
    }

    /**
     * Determine if the given user can update the given provider_availability.
     *
     * @param UserPolicy $user
     * @param ProviderAvailability $provider_availability
     *
     * @return bool
     */
    public function update(UserPolicy $user, ProviderAvailability $provider_availability)
    {
        if ($user->canDo('service.provider_availability.edit') && $user->isAdmin()) {
            return true;
        }

        return $provider_availability->user_id == user_id() && $provider_availability->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given provider_availability.
     *
     * @param UserPolicy $user
     * @param ProviderAvailability $provider_availability
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ProviderAvailability $provider_availability)
    {
        return $provider_availability->user_id == user_id() && $provider_availability->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given provider_availability.
     *
     * @param UserPolicy $user
     * @param ProviderAvailability $provider_availability
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ProviderAvailability $provider_availability)
    {
        if ($user->canDo('service.provider_availability.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given provider_availability.
     *
     * @param UserPolicy $user
     * @param ProviderAvailability $provider_availability
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ProviderAvailability $provider_availability)
    {
        if ($user->canDo('service.provider_availability.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
