<?php

namespace B2buy\Service\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Service\Models\Provider;

class ProviderPolicy
{

    /**
     * Determine if the given user can view the provider.
     *
     * @param UserPolicy $user
     * @param Provider $provider
     *
     * @return bool
     */
    public function view(UserPolicy $user, Provider $provider)
    {
        if ($user->canDo('service.provider.view') && $user->isAdmin()) {
            return true;
        }

        return $provider->user_id == user_id() && $provider->user_type == user_type();
    }

    /**
     * Determine if the given user can create a provider.
     *
     * @param UserPolicy $user
     * @param Provider $provider
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('service.provider.create');
    }

    /**
     * Determine if the given user can update the given provider.
     *
     * @param UserPolicy $user
     * @param Provider $provider
     *
     * @return bool
     */
    public function update(UserPolicy $user, Provider $provider)
    {
        if ($user->canDo('service.provider.edit') && $user->isAdmin()) {
            return true;
        }

        return $provider->user_id == user_id() && $provider->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given provider.
     *
     * @param UserPolicy $user
     * @param Provider $provider
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Provider $provider)
    {
        return $provider->user_id == user_id() && $provider->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given provider.
     *
     * @param UserPolicy $user
     * @param Provider $provider
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Provider $provider)
    {
        if ($user->canDo('service.provider.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given provider.
     *
     * @param UserPolicy $user
     * @param Provider $provider
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Provider $provider)
    {
        if ($user->canDo('service.provider.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
