<?php

namespace B2buy\Service\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Service\Models\Subscription;

class SubscriptionPolicy
{

    /**
     * Determine if the given user can view the subscription.
     *
     * @param UserPolicy $user
     * @param Subscription $subscription
     *
     * @return bool
     */
    public function view(UserPolicy $user, Subscription $subscription)
    {
        if ($user->canDo('service.subscription.view') && $user->isAdmin()) {
            return true;
        }

        return $subscription->user_id == user_id() && $subscription->user_type == user_type();
    }

    /**
     * Determine if the given user can create a subscription.
     *
     * @param UserPolicy $user
     * @param Subscription $subscription
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('service.subscription.create');
    }

    /**
     * Determine if the given user can update the given subscription.
     *
     * @param UserPolicy $user
     * @param Subscription $subscription
     *
     * @return bool
     */
    public function update(UserPolicy $user, Subscription $subscription)
    {
        if ($user->canDo('service.subscription.edit') && $user->isAdmin()) {
            return true;
        }

        return $subscription->user_id == user_id() && $subscription->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given subscription.
     *
     * @param UserPolicy $user
     * @param Subscription $subscription
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Subscription $subscription)
    {
        return $subscription->user_id == user_id() && $subscription->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given subscription.
     *
     * @param UserPolicy $user
     * @param Subscription $subscription
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Subscription $subscription)
    {
        if ($user->canDo('service.subscription.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given subscription.
     *
     * @param UserPolicy $user
     * @param Subscription $subscription
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Subscription $subscription)
    {
        if ($user->canDo('service.subscription.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
