<?php

namespace B2buy\Service\Providers;

use Illuminate\Support\ServiceProvider;

class ServiceServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'service');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'service');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerService();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerService()
    {
        $this->app->bind('service', function($app) {
            return new Service($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Service', 'Lavalite\Service\Facades\Service');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('b2buy.service', function ($app) {
            return $this->app->make('B2buy\Service\Service');
        });

        // Bind Provider to repository
        $this->app->bind(
            'B2buy\Service\Interfaces\ProviderRepositoryInterface',
            \B2buy\Service\Repositories\Eloquent\ProviderRepository::class
        );        // Bind Booking to repository
        $this->app->bind(
            'B2buy\Service\Interfaces\BookingRepositoryInterface',
            \B2buy\Service\Repositories\Eloquent\BookingRepository::class
        );        // Bind Quote to repository
        $this->app->bind(
            'B2buy\Service\Interfaces\QuoteRepositoryInterface',
            \B2buy\Service\Repositories\Eloquent\QuoteRepository::class
        );        // Bind Comment to repository
        $this->app->bind(
            'B2buy\Service\Interfaces\CommentRepositoryInterface',
            \B2buy\Service\Repositories\Eloquent\CommentRepository::class
        );        // Bind Subscription to repository
        $this->app->bind(
            'B2buy\Service\Interfaces\SubscriptionRepositoryInterface',
            \B2buy\Service\Repositories\Eloquent\SubscriptionRepository::class
        );        // Bind ProviderAvailability to repository
        $this->app->bind(
            'B2buy\Service\Interfaces\ProviderAvailabilityRepositoryInterface',
            \B2buy\Service\Repositories\Eloquent\ProviderAvailabilityRepository::class
        );        // Bind Review to repository
        $this->app->bind(
            'B2buy\Service\Interfaces\ReviewRepositoryInterface',
            \B2buy\Service\Repositories\Eloquent\ReviewRepository::class
        );

        $this->app->register(\B2buy\Service\Providers\AuthServiceProvider::class);
        
        $this->app->register(\B2buy\Service\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and service's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'b2buy.service'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeService::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['b2buy.service'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('b2buy/service.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/service')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/service')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
